package com.digiwin.athena.app.service.staff;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.digiwin.app.service.DWEAIResult;
import com.digiwin.athena.app.infra.common.enums.TabStatusEnums;
import com.digiwin.athena.app.infra.entity.StaffEntity;
import com.digiwin.athena.app.infra.repository.StaffRepository;
import com.digiwin.athena.app.infra.service.StaffService;
import com.digiwin.athena.opt.common.eai.EAIUtil;
import com.digiwin.athena.opt.common.eai.service.AbsEAIService;
import com.digiwin.athena.opt.common.security.SecurityUtil;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @Auther: zhenggl
 * @Date: 2023/4/28
 */
public class StaffGetEAIService extends AbsEAIService {

    @Resource
    private StaffRepository staffRepository;

    @Resource
    private StaffService staffService;

    @Override
    public String getServiceName() {
        return StaffUtil.DEMO_WAIT_REGISTER_PERSONNEL_INFO_GET;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public DWEAIResult execute(Map<String, String> headers, String messageBody) throws Exception {
        //查询所有tab_status=0的数据然后把他们全部修改为1
        LambdaQueryWrapper<StaffEntity> lmq = new LambdaQueryWrapper<>();
        lmq.eq(StaffEntity::getTenantSid, SecurityUtil.getUserProfile().getTenantSid());
        lmq.eq(StaffEntity::getTabStatus, TabStatusEnums.NOSET.getValue());
        List<StaffEntity> staffEntities = staffRepository.selectList(lmq);
        if (!CollectionUtils.isEmpty(staffEntities)){
            List<Long> idList = staffEntities.stream().map(StaffEntity::getId).collect(Collectors.toList());
            LambdaUpdateWrapper<StaffEntity> lmu = new LambdaUpdateWrapper<>();
            lmu.set(StaffEntity::getTabStatus,TabStatusEnums.PENDING);
            lmu.in(StaffEntity::getId,idList);
            staffService.update(lmu);
            //修改查询到的参数
            staffEntities.forEach(item ->{
                item.setTabStatus(TabStatusEnums.PENDING.getValue());
            });
        }
        return EAIUtil.buildEAIResult(new JSONObject().fluentPut("wait_register_personnel",staffEntities));
    }
}
